cmd

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 8, 2026 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Profile string    // AWS profile to use for authentication
	Region  string    // AWS region to operate in
	Version = "0.8.0" // Current version of the application
)

Global configuration variables

Functions

func Execute

func Execute() error

Execute runs the root command and handles any errors This is called by main.main() and only needs to happen once

func NewRootCmd

func NewRootCmd() *cobra.Command

NewRootCmd creates and configures the root command for the AWS Simple CLI

Types

This section is empty.

Directories

Path Synopsis
asg
schedule
add.go defines the 'add' subcommand for schedule operations.
add.go defines the 'add' subcommand for schedule operations.
ec2
ami
ls.go defines the 'ls' subcommand for AMI operations.
ls.go defines the 'ls' subcommand for AMI operations.
security_group
ls.go defines the 'ls' subcommand for security group operations.
ls.go defines the 'ls' subcommand for security group operations.
snapshot
ls.go defines the 'ls' subcommand for snapshot operations.
ls.go defines the 'ls' subcommand for snapshot operations.
volume
ls.go defines the 'ls' subcommand for volume operations.
ls.go defines the 'ls' subcommand for volume operations.
ecs
elb
iam
rds
vpc
igw
ls.go defines the 'ls' subcommand for volume operations.
ls.go defines the 'ls' subcommand for volume operations.

Jump to