Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( Profile string // AWS profile to use for authentication Region string // AWS region to operate in Version = "0.8.0" // Current version of the application )
Global configuration variables
Functions ¶
func Execute ¶
func Execute() error
Execute runs the root command and handles any errors This is called by main.main() and only needs to happen once
func NewRootCmd ¶
NewRootCmd creates and configures the root command for the AWS Simple CLI
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
schedule
add.go defines the 'add' subcommand for schedule operations.
|
add.go defines the 'add' subcommand for schedule operations. |
|
ami
ls.go defines the 'ls' subcommand for AMI operations.
|
ls.go defines the 'ls' subcommand for AMI operations. |
|
security_group
ls.go defines the 'ls' subcommand for security group operations.
|
ls.go defines the 'ls' subcommand for security group operations. |
|
snapshot
ls.go defines the 'ls' subcommand for snapshot operations.
|
ls.go defines the 'ls' subcommand for snapshot operations. |
|
volume
ls.go defines the 'ls' subcommand for volume operations.
|
ls.go defines the 'ls' subcommand for volume operations. |
|
igw
ls.go defines the 'ls' subcommand for volume operations.
|
ls.go defines the 'ls' subcommand for volume operations. |
Click to show internal directories.
Click to hide internal directories.