Documentation
¶
Index ¶
- Variables
- func ActionGroups() []*cobra.Group
- func AddShowFlags(cmd *cobra.Command, defaultLayout string)
- func AddTagFlag(cmd *cobra.Command)
- func CreateService[T any](cmd *cobra.Command, createService ServiceCreator[T]) (T, error)
- func DefaultErrorHandler(err error) error
- func GetLayout(cmd *cobra.Command) string
- func GetPersistentFlags(cmd *cobra.Command) (string, string)
- func SubcommandGroups() []*cobra.Group
- func ValidateFlagChoice(cmd *cobra.Command, flag string, choices []string) error
- type ServiceCreator
Constants ¶
This section is empty.
Variables ¶
var ( Tags []string ValidLayouts = []string{"horizontal", "vertical", "grid"} )
Functions ¶
func AddShowFlags ¶ added in v0.0.36
AddShowFlags adds shared flags for the show command with a configurable default layout.
func AddTagFlag ¶ added in v0.0.32
AddTagFlag adds the --tag flag to the command for filtering resources by tags.
func CreateService ¶ added in v0.0.38
func CreateService[T any](cmd *cobra.Command, createService ServiceCreator[T]) (T, error)
func DefaultErrorHandler ¶
DefaultErrorHandler handles AWS smithy.OperationError, context timeouts, and can be extended for other error types.
func GetPersistentFlags ¶
GetPersistentFlags returns the profile and region from the command line flags.
func SubcommandGroups ¶
SubcommandGroups returns the subcommand groups.
Types ¶
Click to show internal directories.
Click to hide internal directories.